Piculet
=======

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   overview
   extract
   preprocess
   low-level
   api
   history


Indices and Tables
==================

* :ref:`genindex`
* :ref:`search`
